# Generated by Django 2.2.4 on 2019-08-21 05:49

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0009_auto_20190821_0110'),
    ]

    operations = [
        migrations.AddField(
            model_name='calendars',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='clndr.Calendars'),
        ),
    ]
